@@ -63,24 +63,24 @@ class Avanzar(Comportamiento):
 
     def iniciar(self, receptor):
         self.receptor = receptor
-
         rotacion_en_radianes = math.radians(-receptor.rotacion)
         self.dx = math.cos(rotacion_en_radianes)
         self.dy = math.sin(rotacion_en_radianes)
 
-        self.to_x = (self.dx * self.pasos) + receptor.x
-        self.to_y = (self.dy * self.pasos) + receptor.y
-
     def actualizar(self):
-        distancia_x = pilas.utils.distancia(self.receptor.x, self.to_x)
-        distancia_y = pilas.utils.distancia(self.receptor.y, self.to_y)
+        salir = False
 
-        # Avanza en la direccion al punto destino y no lo sobrepasa.
-        self.receptor.x += min(self.dx * self.velocidad, distancia_x)
-        self.receptor.y += min(self.dy * self.velocidad, distancia_y)
+        if self.pasos - self.velocidad < 0:
+            avance = self.pasos
+            salir = True
+        else:
+            avance = self.velocidad
 
-        # Termina el movimiento llega al punto destino.
-        if distancia_x < self.velocidad + 1 and distancia_y < self.velocidad + 1:
+        self.pasos -= avance
+        self.receptor.x += self.dx * avance
+        self.receptor.y += self.dy * avance
+
+        if salir:
             return True
 
 class CambiarColor(Comportamiento):
@@ -95,3 +95,30 @@ class CambiarColor(Comportamiento):
     def actualizar(self):
         self.receptor.color = self.nuevo_color
         return True
+
+
+
+class BajarLapiz(Comportamiento):
+
+    def __init__(self):
+        pass
+
+    def iniciar(self, receptor):
+        self.receptor = receptor
+
+    def actualizar(self):
+        self.receptor.pizarra.bajar_lapiz()
+        return True
+
+class SubirLapiz(Comportamiento):
+
+    def __init__(self):
+        pass
+
+    def iniciar(self, receptor):
+        self.receptor = receptor
+
+    def actualizar(self):
+        self.receptor.pizarra.levantar_lapiz()
+        return True
+
